@@ -1,4 +1,3 @@
-{-# LANGUAGE CPP #-}
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 module Data.Binary.Instances.Aeson where
 
@@ -10,12 +9,9 @@ import Data.Binary.Instances.Text ()
 import Data.Binary.Instances.UnorderedContainers ()
 import Data.Binary.Instances.Vector ()
 
-import qualified Data.Aeson as A
-
-#if MIN_VERSION_aeson(2,0,0)
-import qualified Data.Aeson.Key as Key
+import qualified Data.Aeson        as A
+import qualified Data.Aeson.Key    as Key
 import qualified Data.Aeson.KeyMap as KM
-#endif
 
 instance Binary A.Value where
     get = do
@@ -36,7 +32,6 @@ instance Binary A.Value where
     put (A.Bool v)   = put (4 :: Int) >> put v
     put A.Null       = put (5 :: Int)
 
-#if MIN_VERSION_aeson(2,0,0)
 instance Binary Key.Key where
     get = Key.fromText <$> get
     put = put . Key.toText
@@ -44,4 +39,3 @@ instance Binary Key.Key where
 instance Binary v => Binary (KM.KeyMap v) where
     get = fmap KM.fromList get
     put = put . KM.toList
-#endif
